@@ -1,5 +1,7 @@
 from __future__ import print_function
 
+__version__ = '0.5.0'
+
 try:
     raw_input
 except NameError:
@@ -14,16 +16,14 @@ def autoremove(name, yes=False):
     dist = get_distribution(name)
     graph = get_graph()
     dead = find_all_dead(graph, set([dist]))
-    print("Uninstalling:")
     show_tree(dist, dead)
-    if yes or confirm("Proceed (y/N)?"):
+    if yes or confirm("Uninstall (y/N)?"):
         for d in dead:
             remove_dist(d)
 
 
 def show_tree(dist, dead, indent=0):
-    prefix = ' ' * indent * 4
-    print(prefix, end=' ')
+    print(' ' * 4 * indent, end='')
     show_dist(dist)
     for req in requires(dist):
         if req in dead:
@@ -78,10 +78,13 @@ def requires(dist):
     return map(get_distribution, dist.requires())
 
 
-def main():
-    parser = optparse.OptionParser(usage='usage: %prog [-hy] NAME')
+def main(argv=None):
+    parser = optparse.OptionParser(
+        usage='usage: %prog [-hy] NAME',
+        version='%prog ' + __version__,
+    )
     parser.add_option('-y', '--yes', action='store_true', default=False)
-    (opts, args) = parser.parse_args()
+    (opts, args) = parser.parse_args(argv)
     if len(args) != 1:
         parser.error('Incorrect number of arguments')
     autoremove(args[0], opts.yes)
